@@ -1,5 +1,5 @@
 similarity.subjects <- function(data, weights){
   D <- dist.subjects(data, weights=weights)
-  S <- 1 - D^2
+  S <- 1 - D
   return(as.matrix(S))
 }
\ No newline at end of file
